"use strict";
var _dragSourceMonitorImpl = require("../DragSourceMonitorImpl");
var _dndCore = require("dnd-core");
var _reactDndTestBackend = require("react-dnd-test-backend");
describe('The DragSourceMonitorImpl', function() {
    it('can be constructed', function() {
        var manager = (0, _dndCore).createDragDropManager(_reactDndTestBackend.TestBackend);
        var monitor = new _dragSourceMonitorImpl.DragSourceMonitorImpl(manager);
        expect(monitor).toBeDefined();
    });
    it('uses the monitor for canDrag', function() {
        var canDragSource = vi.fn();
        var manager = (0, _dndCore).createDragDropManager(_reactDndTestBackend.TestBackend);
        manager.getMonitor().canDragSource = canDragSource;
        var monitor = new _dragSourceMonitorImpl.DragSourceMonitorImpl(manager);
        monitor.canDragSource('123');
        expect(canDragSource.mock.calls).toHaveLength(1);
        expect(canDragSource.mock.calls[0]).toEqual([
            '123'
        ]);
    });
    it('throws if canDrag is used in a loop', function() {
        var manager = (0, _dndCore).createDragDropManager(_reactDndTestBackend.TestBackend);
        var monitor = new _dragSourceMonitorImpl.DragSourceMonitorImpl(manager);
        manager.getMonitor().canDragSource = function(a) {
            return monitor.canDrag(a);
        };
        expect(function() {
            return monitor.canDragSource('123');
        }).toThrow('You may not call monitor.canDrag() inside your canDrag() implementation. Read more: http://react-dnd.github.io/react-dnd/docs/api/drag-source-monitor');
    });
    it('thunks to monitor methods', function() {
        var manager = (0, _dndCore).createDragDropManager(_reactDndTestBackend.TestBackend);
        var monitor = new _dragSourceMonitorImpl.DragSourceMonitorImpl(manager);
        var THUNK_METHODS = [
            'getTargetIds',
            'isSourcePublic',
            'getSourceId',
            'getItemType',
            'getItem',
            'getDropResult',
            'didDrop',
            'getInitialClientOffset',
            'getInitialSourceClientOffset',
            'getSourceClientOffset',
            'getClientOffset',
            'getDifferenceFromInitialOffset', 
        ];
        THUNK_METHODS.forEach(function(method) {
            var mock = vi.fn();
            manager.getMonitor()[method] = mock;
            monitor[method]();
            expect(mock.mock.calls).toHaveLength(1);
        });
    });
});
