import { Ref, ToRef } from 'vue';
export declare function toRefReactive<T extends object, K extends keyof T>(object: Ref<T>, key: K, defaultValue?: T[K]): ToRef<T[K]>;
export declare function toRefsReactive<T extends object>(ref: Ref<T>): T;
/**
 在Vue3中，由于使用reactive生成的对象不能被重新赋值，所以我们一般采用 `const objRef = ref(object)` 的方式来定义一个需要被重复赋值的对象，但是这样的定义会导致读取对象的属性变得繁琐，例如：
 ```ts
 const objRef = ref({ name: 'H', age: 1 })
 objRef.value.name // 'H'
 objRef.value.age  // 1
 ```
 我希望能通过 toRefsReactive 提供一个快捷读取的方式，并且它可以顺利的和toRefs相结合
 ```ts
 const objRef = ref({ name: 'H', age: 1 })
 const obj = toRefsReactive(objRef)
 const { name, age } = toRefs(toRefsReactive(name, age))
 obj.name // 'H'
 name.value // 'H'
 obj.age // 1
 age.value // 1
 ```
 * */
